@@ -1,24 +1,33 @@
----------------------------------------------------
--- Licensed under the GNU General Public License v2
---  * (c) 2010, Adrian C. <anrxc@sysphere.org>
---  * (c) 2009, Lucas de Vries <lucas@glacicle.com>
----------------------------------------------------
+-- RAM and swap usage widget type for GNU/Linux
+-- Copyright (C) 2010  Adrian C. <anrxc@sysphere.org>
+-- Copyright (C) 2009  Lucas de Vries <lucas@glacicle.com>
+-- Copyright (C) 2017  mutlusun <mutlusun@github.com>
+-- Copyright (C) 2018  Jay Kamat <jaygkamat@gmail.com>
+--
+-- This file is part of Vicious.
+--
+-- Vicious is free software: you can redistribute it and/or modify
+-- it under the terms of the GNU General Public License as
+-- published by the Free Software Foundation, either version 2 of the
+-- License, or (at your option) any later version.
+--
+-- Vicious is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+-- GNU General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with Vicious.  If not, see <https://www.gnu.org/licenses/>.
 
 -- {{{ Grab environment
 local io = { lines = io.lines }
-local setmetatable = setmetatable
 local math = { floor = math.floor }
 local string = { gmatch = string.gmatch }
+local helpers = require"vicious.helpers"
 -- }}}
 
-
--- Mem: provides RAM and Swap usage statistics
--- vicious.widgets.mem
-local mem_linux = {}
-
-
 -- {{{ Memory widget type
-local function worker(format)
+return helpers.setcall(function ()
     local _mem = { buf = {}, swp = {} }
 
     -- Get MEM info
@@ -47,7 +56,5 @@ local function worker(format)
     return {_mem.usep,     _mem.inuse,     _mem.total, _mem.free,
             _mem.swp.usep, _mem.swp.inuse, _mem.swp.t, _mem.swp.f,
             _mem.bcuse }
-end
+end)
 -- }}}
-
-return setmetatable(mem_linux, { __call = function(_, ...) return worker(...) end })
